@@ -19,6 +19,18 @@ class RuleEngineThing(Thing):
         rule_engine.add_event_listener(self.on_event)
         rule_engine.add_cron_listener(self.on_cron)
 
+        self.openhab_uri = Value(self.rule_engine.openhab_uri)
+        self.add_property(
+            Property(self,
+                     'openhab_uri',
+                     self.openhab_uri,
+                     metadata={
+                         'title': 'openhab URI',
+                         'type': 'string',
+                         'description': 'the connected openhab instance',
+                         'readOnly': True
+                     }))
+
         self.last_event = Value("")
         self.add_property(
             Property(self,
@@ -31,6 +43,18 @@ class RuleEngineThing(Thing):
                          'readOnly': True
                      }))
 
+        self.loaded_modules = Value("")
+        self.add_property(
+            Property(self,
+                     'loaded_modules',
+                     self.last_event,
+                     metadata={
+                         'title': 'loaded modules',
+                         'type': 'string',
+                         'description': 'the list of loaded modules',
+                         'readOnly': True
+                     }))
+
         self.last_handled_event = Value("")
         self.add_property(
             Property(self,
@@ -67,6 +91,18 @@ class RuleEngineThing(Thing):
                          'readOnly': True
                      }))
 
+        self.last_item_updates = Value("")
+        self.add_property(
+            Property(self,
+                     'last_item_updates',
+                     self.last_item_updates,
+                     metadata={
+                         'title': 'last successful item updates',
+                         'type': 'string',
+                         'description': 'comma separated list of the newest item updates',
+                         'readOnly': True
+                     }))
+
         self.last_item_update_failed = Value("")
         self.add_property(
             Property(self,
@@ -79,27 +115,23 @@ class RuleEngineThing(Thing):
                          'readOnly': True
                      }))
 
-
         self.ioloop = tornado.ioloop.IOLoop.current()
 
 
     def on_event(self):
-        self.ioloop.add_callback(self.__handle_event)
+        self.ioloop.add_callback(self.__handle)
 
-    def __handle_event(self):
+    def on_cron(self):
+        self.ioloop.add_callback(self.__handle)
+
+    def __handle(self):
+        self.last_cron.notify_of_external_update(self.rule_engine.last_cron)
         self.last_event.notify_of_external_update(self.rule_engine.last_event)
         self.last_handled_event.notify_of_external_update(self.rule_engine.last_handled_event)
         self.last_item_update.notify_of_external_update(self.rule_engine.last_item_update)
         self.last_item_update_failed.notify_of_external_update(self.rule_engine.last_failed_item_update)
-
-    def on_cron(self):
-        self.ioloop.add_callback(self.__handle_cron)
-
-    def __handle_cron(self):
-        self.last_cron.notify_of_external_update(self.rule_engine.last_cron)
-        self.last_item_update.notify_of_external_update(self.rule_engine.last_item_update)
-        self.last_item_update_failed.notify_of_external_update(self.rule_engine.last_failed_item_update)
-
+        self.last_item_updates.notify_of_external_update(", ".join(self.rule_engine.last_item_updates))
+        self.loaded_modules.notify_of_external_update(", ".join(self.rule_engine.loaded_modules))
 
 
 def run_server(port: int, description: str, rule_engine: RuleEngine):
